@@ -90,7 +90,7 @@ class bruhcolorwrapper(Sequence):
 
 __AVAILABLE_COMMANDS__ = ['bruhcolored', 'colors', 'color_codes']
 
-VERSION = (0, 0, 50)
+VERSION = (0, 0, 53)
 
 # GENERATE THE 256 COLORS -> [38;5;#m for color
 COLORS_256 = {}
@@ -165,7 +165,7 @@ RESET_256 = u'\u001b[0m'
 RESET_8   = '\033[0m'
 
 
-def bruhcolored(text, color=None, on_color=None, attrs=None, type="limited"):
+def bruhcolored(text, color=None, on_color=None, attrs=None, support="limited"):
     """
     desc:    Generates the properly escape sequenced string for the 
              user inputeed text
@@ -177,7 +177,7 @@ def bruhcolored(text, color=None, on_color=None, attrs=None, type="limited"):
     returns: wrapper-object for the colored string
     """
     
-    if type == "full":
+    if support == "full":
         text, orig_text = str(text), str(text)
 
         if not color and not on_color and not attrs:
@@ -215,21 +215,21 @@ def bruhcolored(text, color=None, on_color=None, attrs=None, type="limited"):
         return bruhcolorwrapper(orig_text, text + RESET_8)
 
 
-def colors(type="limited"):
+def colors(support="limited"):
     """
     desc:    prints out all of the colors supported
     args:    None
     returns: None
     """
-    if type == "full":
+    if support == "full":
         for i in range(0, len(COLORS_256), 16):
             for j in range(i, i + 16):
-                c = bruhcolored((' ' * (4 - len(str(j)))) + (str(j)), color=j, on_color=231, type="full")
+                c = bruhcolored((' ' * (4 - len(str(j)))) + (str(j)), color=j, on_color=231, support="full")
                 print(f"{c}", end="")
             print()
         for i in range(0, len(COLORS_256), 16):
             for j in range(i, i + 16):
-                c = bruhcolored((' ' * (4 - len(str(j)))) + (str(j)), color=j, on_color=232, type="full")
+                c = bruhcolored((' ' * (4 - len(str(j)))) + (str(j)), color=j, on_color=232, support="full")
                 print(f"{c}", end="")
             print()
     else:
@@ -252,13 +252,8 @@ def colors(type="limited"):
         print()
 
 
-def color_codes(type="limited"):
-    if type == "full":
+def color_codes(support="limited"):
+    if support == "full":
         return list(range(256))
     else:
-        for i, color in enumerate(list(COLORS_8.keys())):
-            if i != 0 and i % 2 == 0:
-                print(f"{color:<15s}", end="")
-                print()
-            else:
-                print(f"{color:<15s}", end={})
+        return list(COLORS_8.keys())
